/**
 * @description 布局配置
 * @methods setThemeConfig 设置布局配置
 */
// 布局配置
declare interface ThemeConfigState {
  isDrawer: boolean;
  primary: string;
  isIsDark: boolean;
  appScope: string;
  callCenterType: string;
  cityName: string;
  cityCode: string;
  cityAbbr: string;
  locationCenter: number[];
  faviconImage: string; // favicon
  callCenterSocketUrl: string;
  [x: string]: any;
}
declare interface ThemeConfigStates {
  themeConfig: ThemeConfigState;
}
import { defineStore } from "pinia";
export const useThemeConfig = defineStore("themeConfig", {
  state: (): ThemeConfigStates => ({
    themeConfig: {
      // 是否开启布局配置抽屉
      isDrawer: false,
      /**
       * 全局主题
       */

      primary: "#4e84fd", // 默认 primary 主题颜色
      isIsDark: true, // 是否开启深色模式
      // 当前城市
      appScope: "",
      callCenterType: "", // 呼叫中心类型
      isScale: true, // 是否进行全局适配
      cityName: "", // 城市名称
      cityCode: "", // 6位区号
      cityAbbr: "", // 城市简称
      locationCenter: [], // 城市中心点
      faviconImage: "", // favicon
      callCenterSocketUrl: "", // 呼叫中心socket地址
    },
  }),
  actions: {
    setThemeConfig(data: any) {
      this.themeConfig = data;
    },
  },
  // 开启数据缓存
  persist: {
    enabled: true,
    strategies: [
      {
        //key的名称
        key: `${import.meta.env.VITE_STORAGE_NAME}_themeConfig`,
        storage: sessionStorage,
      },
    ],
  },
});
